
.. _pool-controllers:

=====================
Writting Controllers
=====================

This chapter provides the necessary information to write controllers in sardana.
The complete controller :term:`API` can be found :ref:`here <pool-controller-api>`.

An overview of the pool controller concept can be found 
:ref:`here <pool-controller-overview>`.


Getting started
----------------

A controller in sardana ...

.. todo:: document how to write pool controllers
